==> ejc-settle-api-3.0.0-20240621.092135-65-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetSubVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 施工辅助工程
 *
 * @author generator
 */
public class SettlementCenterBudgetSubVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetSubId; // ejc_income_budget_sub主键
    private Long budgetId; // 预算书主键
    private Long parentId; // 父ID
    private String detailIndex; // 序号
    private String subCode; // 编码
    private String subName; // 名称
    private String subFeature; // 特征
    private String subUnit; // 单位
    private BigDecimal subNum; // 承包合同工程量
    private BigDecimal quoteSubNum; // 对甲结算工程量
    private BigDecimal settlementCenterSubNum; // 统计工程量
    private BigDecimal subTaxRate; // 税率
    private BigDecimal subPrice; // 综合单价(无税)
    private BigDecimal subTaxPrice; // 综合单价(含税)
    private BigDecimal subMny; // 承包合同合价(无税)
    private BigDecimal subTaxMny; // 承包合同合价(含税)
    private BigDecimal subTax; // 承包合同税额
    private BigDecimal quoteSubMny; // 对甲结算产值(无税)
    private BigDecimal quoteSubTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteSubTax; // 结算产值税额
    private BigDecimal settlementCenterSubMny; // 统计产值(无税)
    private BigDecimal settlementCenterSubTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterSubTax; // 统计产值税额
    private String subMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long subSubjectId; // 成本科目id
    private String subSubjectName; // 成本科目名称
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存
    private String errorMessage;//错误信息集合
    private Integer rowIndex;

    private BigDecimal settlementCenterSubNumTotal; // 累计统计工程量
    private BigDecimal settlementCenterSubMnyTotal; // 累计统计产值(无税)
    private BigDecimal settlementCenterSubTaxMnyTotal; // 累计统计产值(含税)
    private BigDecimal settlementCenterSubTaxTotal; // 累计统计产值税额

    private List<SettlementCenterBudgetSubVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetSubId() {
        return budgetSubId;
    }

    public void setBudgetSubId(Long budgetSubId) {
        this.budgetSubId = budgetSubId;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public String getSubCode() {
        return subCode;
    }

    public void setSubCode(String subCode) {
        this.subCode = subCode;
    }

    public String getSubName() {
        return subName;
    }

    public void setSubName(String subName) {
        this.subName = subName;
    }

    public String getSubFeature() {
        return subFeature;
    }

    public void setSubFeature(String subFeature) {
        this.subFeature = subFeature;
    }

    public String getSubUnit() {
        return subUnit;
    }

    public void setSubUnit(String subUnit) {
        this.subUnit = subUnit;
    }

    public BigDecimal getSubNum() {
        return subNum;
    }

    public void setSubNum(BigDecimal subNum) {
        this.subNum = subNum;
    }

    public BigDecimal getQuoteSubNum() {
        return quoteSubNum;
    }

    public void setQuoteSubNum(BigDecimal quoteSubNum) {
        this.quoteSubNum = quoteSubNum;
    }

    public BigDecimal getSettlementCenterSubNum() {
        return settlementCenterSubNum;
    }

    public void setSettlementCenterSubNum(BigDecimal settlementCenterSubNum) {
        this.settlementCenterSubNum = settlementCenterSubNum;
    }

    public BigDecimal getSubTaxRate() {
        return subTaxRate;
    }

    public void setSubTaxRate(BigDecimal subTaxRate) {
        this.subTaxRate = subTaxRate;
    }

    public BigDecimal getSubPrice() {
        return subPrice;
    }

    public void setSubPrice(BigDecimal subPrice) {
        this.subPrice = subPrice;
    }

    public BigDecimal getSubTaxPrice() {
        return subTaxPrice;
    }

    public void setSubTaxPrice(BigDecimal subTaxPrice) {
        this.subTaxPrice = subTaxPrice;
    }

    public BigDecimal getSubMny() {
        return subMny;
    }

    public void setSubMny(BigDecimal subMny) {
        this.subMny = subMny;
    }

    public BigDecimal getSubTaxMny() {
        return subTaxMny;
    }

    public void setSubTaxMny(BigDecimal subTaxMny) {
        this.subTaxMny = subTaxMny;
    }

    public BigDecimal getSubTax() {
        return subTax;
    }

    public void setSubTax(BigDecimal subTax) {
        this.subTax = subTax;
    }

    public BigDecimal getQuoteSubMny() {
        return quoteSubMny;
    }

    public void setQuoteSubMny(BigDecimal quoteSubMny) {
        this.quoteSubMny = quoteSubMny;
    }

    public BigDecimal getQuoteSubTaxMny() {
        return quoteSubTaxMny;
    }

    public void setQuoteSubTaxMny(BigDecimal quoteSubTaxMny) {
        this.quoteSubTaxMny = quoteSubTaxMny;
    }

    public BigDecimal getQuoteSubTax() {
        return quoteSubTax;
    }

    public void setQuoteSubTax(BigDecimal quoteSubTax) {
        this.quoteSubTax = quoteSubTax;
    }

    public BigDecimal getSettlementCenterSubMny() {
        return settlementCenterSubMny;
    }

    public void setSettlementCenterSubMny(BigDecimal settlementCenterSubMny) {
        this.settlementCenterSubMny = settlementCenterSubMny;
    }

    public BigDecimal getSettlementCenterSubTaxMny() {
        return settlementCenterSubTaxMny;
    }

    public void setSettlementCenterSubTaxMny(BigDecimal settlementCenterSubTaxMny) {
        this.settlementCenterSubTaxMny = settlementCenterSubTaxMny;
    }

    public BigDecimal getSettlementCenterSubTax() {
        return settlementCenterSubTax;
    }

    public void setSettlementCenterSubTax(BigDecimal settlementCenterSubTax) {
        this.settlementCenterSubTax = settlementCenterSubTax;
    }

    public String getSubMemo() {
        return subMemo;
    }

    public void setSubMemo(String subMemo) {
        this.subMemo = subMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }

    public Long getSubSubjectId() {
        return subSubjectId;
    }

    public void setSubSubjectId(Long subSubjectId) {
        this.subSubjectId = subSubjectId;
    }

    public String getSubSubjectName() {
        return subSubjectName;
    }

    public void setSubSubjectName(String subSubjectName) {
        this.subSubjectName = subSubjectName;
    }

    public List<SettlementCenterBudgetSubVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetSubVO> children) {
        this.children = children;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public Integer getRowIndex() {
        return rowIndex;
    }

    public void setRowIndex(Integer rowIndex) {
        this.rowIndex = rowIndex;
    }

    public BigDecimal getSettlementCenterSubNumTotal() {
        return settlementCenterSubNumTotal;
    }

    public void setSettlementCenterSubNumTotal(BigDecimal settlementCenterSubNumTotal) {
        this.settlementCenterSubNumTotal = settlementCenterSubNumTotal;
    }

    public BigDecimal getSettlementCenterSubMnyTotal() {
        return settlementCenterSubMnyTotal;
    }

    public void setSettlementCenterSubMnyTotal(BigDecimal settlementCenterSubMnyTotal) {
        this.settlementCenterSubMnyTotal = settlementCenterSubMnyTotal;
    }

    public BigDecimal getSettlementCenterSubTaxMnyTotal() {
        return settlementCenterSubTaxMnyTotal;
    }

    public void setSettlementCenterSubTaxMnyTotal(BigDecimal settlementCenterSubTaxMnyTotal) {
        this.settlementCenterSubTaxMnyTotal = settlementCenterSubTaxMnyTotal;
    }

    public BigDecimal getSettlementCenterSubTaxTotal() {
        return settlementCenterSubTaxTotal;
    }

    public void setSettlementCenterSubTaxTotal(BigDecimal settlementCenterSubTaxTotal) {
        this.settlementCenterSubTaxTotal = settlementCenterSubTaxTotal;
    }
}

==> ejc-settle-api-3.0.0-20241105.061549-115-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetSubVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 施工辅助工程
 *
 * @author generator
 */
public class SettlementCenterBudgetSubVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetSubId; // ejc_income_budget_sub主键
    private Long budgetId; // 预算书主键
    private Long parentId; // 父ID
    private String detailIndex; // 序号
    private String subCode; // 编码
    private String subName; // 名称
    private String subFeature; // 特征
    private String subUnit; // 单位
    private BigDecimal subNum; // 承包合同工程量
    private BigDecimal quoteSubNum; // 对甲结算工程量
    private BigDecimal settlementCenterSubNum; // 统计工程量
    private BigDecimal subTaxRate; // 税率
    private BigDecimal subPrice; // 综合单价(无税)
    private BigDecimal subTaxPrice; // 综合单价(含税)
    private BigDecimal subMny; // 承包合同合价(无税)
    private BigDecimal subTaxMny; // 承包合同合价(含税)
    private BigDecimal subTax; // 承包合同税额
    private BigDecimal quoteSubMny; // 对甲结算产值(无税)
    private BigDecimal quoteSubTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteSubTax; // 结算产值税额
    private BigDecimal settlementCenterSubMny; // 统计产值(无税)
    private BigDecimal settlementCenterSubTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterSubTax; // 统计产值税额
    private String subMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long subSubjectId; // 成本科目id
    private String subSubjectName; // 成本科目名称
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存
    private String errorMessage;//错误信息集合
    private Integer rowIndex;

    private BigDecimal settlementCenterSubNumTotal; // 累计统计工程量
    private BigDecimal settlementCenterSubMnyTotal; // 累计统计产值(无税)
    private BigDecimal settlementCenterSubTaxMnyTotal; // 累计统计产值(含税)
    private BigDecimal settlementCenterSubTaxTotal; // 累计统计产值税额

    private List<SettlementCenterBudgetSubVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetSubId() {
        return budgetSubId;
    }

    public void setBudgetSubId(Long budgetSubId) {
        this.budgetSubId = budgetSubId;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public String getSubCode() {
        return subCode;
    }

    public void setSubCode(String subCode) {
        this.subCode = subCode;
    }

    public String getSubName() {
        return subName;
    }

    public void setSubName(String subName) {
        this.subName = subName;
    }

    public String getSubFeature() {
        return subFeature;
    }

    public void setSubFeature(String subFeature) {
        this.subFeature = subFeature;
    }

    public String getSubUnit() {
        return subUnit;
    }

    public void setSubUnit(String subUnit) {
        this.subUnit = subUnit;
    }

    public BigDecimal getSubNum() {
        return subNum;
    }

    public void setSubNum(BigDecimal subNum) {
        this.subNum = subNum;
    }

    public BigDecimal getQuoteSubNum() {
        return quoteSubNum;
    }

    public void setQuoteSubNum(BigDecimal quoteSubNum) {
        this.quoteSubNum = quoteSubNum;
    }

    public BigDecimal getSettlementCenterSubNum() {
        return settlementCenterSubNum;
    }

    public void setSettlementCenterSubNum(BigDecimal settlementCenterSubNum) {
        this.settlementCenterSubNum = settlementCenterSubNum;
    }

    public BigDecimal getSubTaxRate() {
        return subTaxRate;
    }

    public void setSubTaxRate(BigDecimal subTaxRate) {
        this.subTaxRate = subTaxRate;
    }

    public BigDecimal getSubPrice() {
        return subPrice;
    }

    public void setSubPrice(BigDecimal subPrice) {
        this.subPrice = subPrice;
    }

    public BigDecimal getSubTaxPrice() {
        return subTaxPrice;
    }

    public void setSubTaxPrice(BigDecimal subTaxPrice) {
        this.subTaxPrice = subTaxPrice;
    }

    public BigDecimal getSubMny() {
        return subMny;
    }

    public void setSubMny(BigDecimal subMny) {
        this.subMny = subMny;
    }

    public BigDecimal getSubTaxMny() {
        return subTaxMny;
    }

    public void setSubTaxMny(BigDecimal subTaxMny) {
        this.subTaxMny = subTaxMny;
    }

    public BigDecimal getSubTax() {
        return subTax;
    }

    public void setSubTax(BigDecimal subTax) {
        this.subTax = subTax;
    }

    public BigDecimal getQuoteSubMny() {
        return quoteSubMny;
    }

    public void setQuoteSubMny(BigDecimal quoteSubMny) {
        this.quoteSubMny = quoteSubMny;
    }

    public BigDecimal getQuoteSubTaxMny() {
        return quoteSubTaxMny;
    }

    public void setQuoteSubTaxMny(BigDecimal quoteSubTaxMny) {
        this.quoteSubTaxMny = quoteSubTaxMny;
    }

    public BigDecimal getQuoteSubTax() {
        return quoteSubTax;
    }

    public void setQuoteSubTax(BigDecimal quoteSubTax) {
        this.quoteSubTax = quoteSubTax;
    }

    public BigDecimal getSettlementCenterSubMny() {
        return settlementCenterSubMny;
    }

    public void setSettlementCenterSubMny(BigDecimal settlementCenterSubMny) {
        this.settlementCenterSubMny = settlementCenterSubMny;
    }

    public BigDecimal getSettlementCenterSubTaxMny() {
        return settlementCenterSubTaxMny;
    }

    public void setSettlementCenterSubTaxMny(BigDecimal settlementCenterSubTaxMny) {
        this.settlementCenterSubTaxMny = settlementCenterSubTaxMny;
    }

    public BigDecimal getSettlementCenterSubTax() {
        return settlementCenterSubTax;
    }

    public void setSettlementCenterSubTax(BigDecimal settlementCenterSubTax) {
        this.settlementCenterSubTax = settlementCenterSubTax;
    }

    public String getSubMemo() {
        return subMemo;
    }

    public void setSubMemo(String subMemo) {
        this.subMemo = subMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    @ReferSerialTransfer(referCode = "subject-project-org-ref")
    public Long getSubSubjectId() {
        return subSubjectId;
    }
    @ReferDeserialTransfer
    public void setSubSubjectId(Long subSubjectId) {
        this.subSubjectId = subSubjectId;
    }

    public String getSubSubjectName() {
        return subSubjectName;
    }

    public void setSubSubjectName(String subSubjectName) {
        this.subSubjectName = subSubjectName;
    }

    public List<SettlementCenterBudgetSubVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetSubVO> children) {
        this.children = children;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public Integer getRowIndex() {
        return rowIndex;
    }

    public void setRowIndex(Integer rowIndex) {
        this.rowIndex = rowIndex;
    }

    public BigDecimal getSettlementCenterSubNumTotal() {
        return settlementCenterSubNumTotal;
    }

    public void setSettlementCenterSubNumTotal(BigDecimal settlementCenterSubNumTotal) {
        this.settlementCenterSubNumTotal = settlementCenterSubNumTotal;
    }

    public BigDecimal getSettlementCenterSubMnyTotal() {
        return settlementCenterSubMnyTotal;
    }

    public void setSettlementCenterSubMnyTotal(BigDecimal settlementCenterSubMnyTotal) {
        this.settlementCenterSubMnyTotal = settlementCenterSubMnyTotal;
    }

    public BigDecimal getSettlementCenterSubTaxMnyTotal() {
        return settlementCenterSubTaxMnyTotal;
    }

    public void setSettlementCenterSubTaxMnyTotal(BigDecimal settlementCenterSubTaxMnyTotal) {
        this.settlementCenterSubTaxMnyTotal = settlementCenterSubTaxMnyTotal;
    }

    public BigDecimal getSettlementCenterSubTaxTotal() {
        return settlementCenterSubTaxTotal;
    }

    public void setSettlementCenterSubTaxTotal(BigDecimal settlementCenterSubTaxTotal) {
        this.settlementCenterSubTaxTotal = settlementCenterSubTaxTotal;
    }
}
